@@ -9,7 +9,7 @@ from chaoslib.exceptions import ActivityFailed
 from chaoslib.types import Configuration, DiscoveredActivities, Discovery, Secrets
 from logzero import logger
 
-__version__ = "0.3.0"
+__version__ = "0.4.0"
 __all__ = ["get_session", "discover"]
 RELIABLY_CONFIG_PATH = "~/.config/reliably/config.yaml"
 RELIABLY_HOST = "reliably.com"
@@ -27,7 +27,8 @@ def get_session(
     with httpx.Client() as client:
         client.headers = httpx.Headers(headers)
         client.base_url = httpx.URL(
-            f"https://{auth_info['host']}/entities/{auth_info['org']}/reliably.com/v1"
+            f"https://{auth_info['host']}/api/entities/"
+            f"{auth_info['org']}/reliably.com/v1"
         )
         yield client
 
