@@ -74,7 +74,7 @@ def before_experiment_control(
             "name": "chaosreliably",
             "provider": {
                 "type": "python",
-                "module": "chaosreliably.controls"
+                "module": "chaosreliably.controls",
                 "arguments": {
                     "commit_hash": "59f9f577e2d90719098f4d23d26329ce41f2d0bd",
                     "source": "https://github.com/chaostoolkit-incubator/chaostoolkit-reliably/exp.json",  # Noqa
@@ -90,7 +90,7 @@ def before_experiment_control(
             "name": "chaosreliably",
             "provider": {
                 "type": "python",
-                "module": "chaosreliably.controls"
+                "module": "chaosreliably.controls",
                 "arguments": {
                     "commit_hash": "59f9f577e2d90719098f4d23d26329ce41f2d0bd",
                     "source": "https://github.com/chaostoolkit-incubator/chaostoolkit-reliably/exp.json",  # Noqa
@@ -107,6 +107,7 @@ def before_experiment_control(
     ]
     """
     try:
+        reliably_secrets = secrets.get("reliably", None) if secrets else None
         commit_hash = kwargs.get("commit_hash")
         source = kwargs.get("source")
         user = kwargs.get("user")
@@ -127,13 +128,13 @@ def before_experiment_control(
                 source=source,
                 user=user,
                 configuration=configuration,
-                secrets=secrets,
+                secrets=reliably_secrets,
                 experiment_related_to_labels=experiment_related_to_labels,
             )
         )
 
         configuration.update(
-            {"chaosreliably": {"experiment_run_labels": experiment_run_labels.dict()}}
+            {"chaosreliably": {"experiment_run_labels": experiment_run_labels}}
         )
     except Exception as ex:
         logger.debug(
@@ -166,6 +167,7 @@ def after_experiment_control(
     :param **kwargs: Any additional keyword arguments passed to the control
     """
     try:
+        reliably_secrets = secrets.get("reliably", None) if secrets else None
         _create_experiment_event(
             event_type=EventType.EXPERIMENT_END,
             name=f"Experiment: {context['title']} - Ended",
@@ -174,7 +176,7 @@ def after_experiment_control(
                 "experiment_run_labels"
             ],
             configuration=configuration,
-            secrets=secrets,
+            secrets=reliably_secrets,
         )
     except Exception as ex:
         logger.debug(
@@ -204,6 +206,7 @@ def before_hypothesis_control(
     :param **kwargs: Any additional keyword arguments passed to the control
     """
     try:
+        reliably_secrets = secrets.get("reliably", None) if secrets else None
         _create_experiment_event(
             event_type=EventType.HYPOTHESIS_START,
             name=context["title"],
@@ -212,7 +215,7 @@ def before_hypothesis_control(
                 "experiment_run_labels"
             ],
             configuration=configuration,
-            secrets=secrets,
+            secrets=reliably_secrets,
         )
     except Exception as ex:
         logger.debug(
@@ -245,6 +248,7 @@ def after_hypothesis_control(
     :param **kwargs: Any additional keyword arguments passed to the control
     """
     try:
+        reliably_secrets = secrets.get("reliably", None) if secrets else None
         _create_experiment_event(
             event_type=EventType.HYPOTHESIS_END,
             name=context["title"],
@@ -253,7 +257,7 @@ def after_hypothesis_control(
                 "experiment_run_labels"
             ],
             configuration=configuration,
-            secrets=secrets,
+            secrets=reliably_secrets,
         )
     except Exception as ex:
         logger.debug(
@@ -282,6 +286,7 @@ def before_method_control(
     :param **kwargs: Any additional keyword arguments passed to the control
     """
     try:
+        reliably_secrets = secrets.get("reliably", None) if secrets else None
         _create_experiment_event(
             event_type=EventType.METHOD_START,
             name=f"{context['title']} - Method Start",
@@ -290,7 +295,7 @@ def before_method_control(
                 "experiment_run_labels"
             ],
             configuration=configuration,
-            secrets=secrets,
+            secrets=reliably_secrets,
         )
     except Exception as ex:
         logger.debug(
@@ -322,6 +327,7 @@ def after_method_control(
     :param **kwargs: Any additional keyword arguments passed to the control
     """
     try:
+        reliably_secrets = secrets.get("reliably", None) if secrets else None
         _create_experiment_event(
             event_type=EventType.METHOD_END,
             name=f"{context['title']} - Method End",
@@ -330,7 +336,7 @@ def after_method_control(
                 "experiment_run_labels"
             ],
             configuration=configuration,
-            secrets=secrets,
+            secrets=reliably_secrets,
         )
     except Exception as ex:
         logger.debug(
@@ -359,6 +365,7 @@ def before_rollback_control(
     :param **kwargs: Any additional keyword arguments passed to the control
     """
     try:
+        reliably_secrets = secrets.get("reliably", None) if secrets else None
         _create_experiment_event(
             event_type=EventType.ROLLBACK_START,
             name=f"{context['title']} - Rollback Start",
@@ -367,7 +374,7 @@ def before_rollback_control(
                 "experiment_run_labels"
             ],
             configuration=configuration,
-            secrets=secrets,
+            secrets=reliably_secrets,
         )
     except Exception as ex:
         logger.debug(
@@ -399,6 +406,7 @@ def after_rollback_control(
     :param **kwargs: Any additional keyword arguments passed to the control
     """
     try:
+        reliably_secrets = secrets.get("reliably", None) if secrets else None
         _create_experiment_event(
             event_type=EventType.ROLLBACK_END,
             name=f"{context['title']} - Rollback End",
@@ -407,7 +415,7 @@ def after_rollback_control(
                 "experiment_run_labels"
             ],
             configuration=configuration,
-            secrets=secrets,
+            secrets=reliably_secrets,
         )
     except Exception as ex:
         logger.debug(
@@ -437,6 +445,7 @@ def before_activity_control(
     :param **kwargs: Any additional keyword arguments passed to the control
     """
     try:
+        reliably_secrets = secrets.get("reliably", None) if secrets else None
         _create_experiment_event(
             event_type=EventType.ACTIVITY_START,
             name=context["name"],
@@ -445,7 +454,7 @@ def before_activity_control(
                 "experiment_run_labels"
             ],
             configuration=configuration,
-            secrets=secrets,
+            secrets=reliably_secrets,
         )
     except Exception as ex:
         logger.debug(
@@ -477,6 +486,7 @@ def after_activity_control(
     :param **kwargs: Any additional keyword arguments passed to the control
     """
     try:
+        reliably_secrets = secrets.get("reliably", None) if secrets else None
         _create_experiment_event(
             event_type=EventType.ACTIVITY_END,
             name=context["name"],
@@ -485,7 +495,7 @@ def after_activity_control(
                 "experiment_run_labels"
             ],
             configuration=configuration,
-            secrets=secrets,
+            secrets=reliably_secrets,
         )
     except Exception as ex:
         logger.debug(
@@ -538,7 +548,10 @@ def _create_experiment(
     created_entity = _create_entity_context_on_reliably(
         entity_context=experiment_entity, configuration=configuration, secrets=secrets
     )
-    return cast(EntityContextExperimentLabels, created_entity.metadata.labels)
+    return cast(
+        EntityContextExperimentLabels,
+        created_entity.metadata.labels.dict(by_alias=True),
+    )
 
 
 def _create_experiment_version(
@@ -578,7 +591,10 @@ def _create_experiment_version(
         configuration=configuration,
         secrets=secrets,
     )
-    return cast(EntityContextExperimentVersionLabels, created_entity.metadata.labels)
+    return cast(
+        EntityContextExperimentVersionLabels,
+        created_entity.metadata.labels.dict(by_alias=True),
+    )
 
 
 def _create_experiment_run(
@@ -611,7 +627,10 @@ def _create_experiment_run(
         configuration=configuration,
         secrets=secrets,
     )
-    return cast(EntityContextExperimentRunLabels, created_entity.metadata.labels)
+    return cast(
+        EntityContextExperimentRunLabels,
+        created_entity.metadata.labels.dict(by_alias=True),
+    )
 
 
 def _create_experiment_event(
@@ -639,7 +658,7 @@ def _create_experiment_event(
     experiment_event_entity = EntityContext(
         metadata=EntityContextMetadata(
             labels=EntityContextExperimentEventLabels(
-                event_type=event_type.value, name=name, output=output
+                event_type=event_type.value, name=name, output=str(output)
             ),
             related_to=[experiment_run_labels],
         )
@@ -650,7 +669,10 @@ def _create_experiment_event(
         configuration=configuration,
         secrets=secrets,
     )
-    return cast(EntityContextExperimentEventLabels, created_entity.metadata.labels)
+    return cast(
+        EntityContextExperimentEventLabels,
+        created_entity.metadata.labels.dict(by_alias=True),
+    )
 
 
 def _create_experiment_entities_for_before_experiment_control(
